pub struct EqualityDeleteFile {
pub path: String,
pub equality_ids: Vec<i32>,
pub record_count: u64,
pub file_size_bytes: u64,
}Expand description
Reference to an Iceberg equality delete file (Phase H).
The delete file is an Avro file with content=2 whose rows contain equality
predicates — any data row matching one of those rows is logically deleted.
equality_ids lists the field IDs used for the equality check.
Fields
path: StringAbsolute or warehouse-relative path of the Avro delete file.
equality_ids: Vec<i32>Field IDs whose values must all match to delete a data row.
record_count: u64Number of predicates (rows) in the delete file.
file_size_bytes: u64Trait Implementations
Sourceimpl Clone for EqualityDeleteFile
impl Clone for EqualityDeleteFile
Sourcefn clone(&self) -> EqualityDeleteFile
fn clone(&self) -> EqualityDeleteFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EqualityDeleteFile
impl Debug for EqualityDeleteFile
Sourceimpl<'de> Deserialize<'de> for EqualityDeleteFile
impl<'de> Deserialize<'de> for EqualityDeleteFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more