pub struct SchemaEvolution {
pub renames: Vec<RenameColumnRequest>,
pub adds: Vec<AddColumnRequest>,
}Expand description
Atomic schema evolution transaction applied in a single metadata.json rewrite.
Operations are applied in order: renames first (so you can rename a column and also add a new column with the old name in one call), then additions.
Fields
renames: Vec<RenameColumnRequest>adds: Vec<AddColumnRequest>Implementations
Sourceimpl SchemaEvolution
impl SchemaEvolution
pub fn new() -> Self
pub fn add_column(self, req: AddColumnRequest) -> Self
pub fn rename_column( self, old_name: impl Into<String>, new_name: impl Into<String>, ) -> Self